@@ -1,5 +1,5 @@
 package DBIx::Class::DeploymentHandler;
-$DBIx::Class::DeploymentHandler::VERSION = '0.002211';
+$DBIx::Class::DeploymentHandler::VERSION = '0.002213';
 # ABSTRACT: Extensible DBIx::Class deployment
 
 use Moose;
@@ -160,6 +160,48 @@ L<DBIx::Class::DeploymentHandler::VersionHandler::Monotonic>,
 L<DBIx::Class::DeploymentHandler::VersionStorage::Standard>, and
 L<DBIx::Class::DeploymentHandler::WithReasonableDefaults>.
 
+=head1 WHY IS THIS SO WEIRD
+
+C<DBIx::Class::DeploymentHandler> has a strange structure.  The gist is that it
+delegates to three small objects that are proxied to via interface roles that
+then create the illusion of one large, monolithic object.  Here is a diagram
+that might help:
+
+                    +------------+
+                    |            |
+       +------------+ Deployment +-----------+
+       |            |  Handler   |           |
+       |            |            |           |
+       |            +-----+------+           |
+       |                  |                  |
+       |                  |                  |
+       :                  :                  :
+       v                  v                  v
+  /-=-------\        /-=-------\       /-=----------\
+  |         |        |         |       |            |  (interface roles)
+  | Handles |        | Handles |       |  Handles   |
+  | Version |        | Deploy  |       | Versioning |
+  | Storage |        |         |       |            |
+  |         |        \-+--+--+-/       \-+---+---+--/
+  \-+--+--+-/          |  |  |           |   |   |
+    |  |  |            |  |  |           |   |   |
+    |  |  |            |  |  |           |   |   |
+    v  v  v            v  v  v           v   v   v
+ +----------+        +--------+        +-----------+
+ |          |        |        |        |           |  (implementations)
+ | Version  |        | Deploy |        |  Version  |
+ | Storage  |        | Method |        |  Handler  |
+ | Standard |        | SQLT   |        | Monotonic |
+ |          |        |        |        |           |
+ +----------+        +--------+        +-----------+
+
+The nice thing about this is that we have well defined interfaces for the
+objects that comprise the C<DeploymentHandler>, the smaller objects can be
+tested in isolation, and the smaller objects can even be swapped in easily.  But
+the real win is that you can subclass the C<DeploymentHandler> without knowing
+about the underlying delegation; you just treat it like normal Perl and write
+methods that do what you want.
+
 =head1 THIS SUCKS
 
 You started your project and weren't using C<DBIx::Class::DeploymentHandler>?
